@@ -76,7 +76,7 @@ def juvare_send_task(text: str, to: str, event: int):
                 if content and isinstance(content, dict) and content.get("message"):
                     message += f"It said: {content['message']}"
                 else:
-                    message += f"It contained no further message to explain the error."
+                    message += "It contained no further message to explain the error."
             except Exception:
                 message += "It had no readable JSON body with details."
             logger.error(message)
@@ -88,31 +88,34 @@ def juvare_send(*args, **kwargs):
 
 @app.task(acks_late=True)
 def send_bulk_sms(event: Event, user: int, message: dict, orders: list) -> None:
-    failures = []
-    message = LazyI18nString(message)
-    user = User.objects.get(pk=user) if user else None
-    orders = Order.objects.filter(pk__in=orders, event=event)
     event = Event.objects.get(pk=event)
 
-    for o in orders:
+    with scope(organizer=event.organizer):
+        orders = Order.objects.filter(pk__in=orders, event=event)
+        message = LazyI18nString(message)
+        user = User.objects.get(pk=user) if user else None
 
-        if o.phone:
-            try:
-                ia = o.invoice_address
-            except InvoiceAddress.DoesNotExist:
-                ia = InvoiceAddress(order=o)
+        for o in orders:
 
-            try:
-                with language(o.locale, event.settings.region):
-                    email_context = get_email_context(
-                        event=event, order=o, position_or_address=ia
+            if o.phone:
+                try:
+                    ia = o.invoice_address
+                except InvoiceAddress.DoesNotExist:
+                    ia = InvoiceAddress(order=o)
+
+                try:
+                    with language(o.locale, event.settings.region):
+                        email_context = get_email_context(
+                            event=event, order=o, position_or_address=ia
+                        )
+                        message = str(message).format_map(TolerantDict(email_context))
+                        juvare_send(text=message, to=str(o.phone), event=event.pk)
+                        o.log_action(
+                            "pretix.plugins.pretix_juvare_notify.order.sms.sent",
+                            user=user,
+                            data={"message": message, "recipient": str(o.phone)},
+                        )
+                except Exception as e:
+                    logger.error(
+                        f"Failed to send part of a bulk message for order {o.code} ({event.slug}):\n{e}"
                     )
-                    message = str(message).format_map(TolerantDict(email_context))
-                    juvare_send(text=message, to=str(o.phone), event=event.pk)
-                    o.log_action(
-                        "pretix.plugins.pretix_juvare_notify.order.sms.sent",
-                        user=user,
-                        data={"message": message, "recipient": str(o.phone)},
-                    )
-            except Exception:
-                failures.append(str(o.phone))
