@@ -8,6 +8,16 @@ urlpatterns = [
     #     views.EventSettings.as_view(),
     #     name="event-settings",
     # ),
+    url(
+        r"^control/event/(?P<organizer>[^/]+)/(?P<event>[^/]+)/juvare-notify/$",
+        views.SenderView.as_view(),
+        name="send",
+    ),
+    url(
+        r"^control/event/(?P<organizer>[^/]+)/(?P<event>[^/]+)/juvare-notify/history/",
+        views.SMSHistoryView.as_view(),
+        name="history",
+    ),
     url(
         r"^control/event/(?P<organizer>[^/]+)/juvare-notify$",
         views.OrganizerSettings.as_view(),
